from .cps import (
    CPS_2020,
    CPS_2021,
    CPS_2022,
    CPS_2023,
    RawCPS_2020,
    RawCPS_2021,
    CalibratedCPS_2023,
)

DATASETS = [CPS_2020, CPS_2021, CPS_2022, CPS_2023, CalibratedCPS_2023]
